Arcana Extension - bids
=======================
.. image:: https://github.com/arcanaframework/arcana-bids/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/arcanaframework/arcana-bids/actions/workflows/tests.yml
.. image:: https://codecov.io/gh/arcanaframework/arcana-bids/branch/main/graph/badge.svg?token=UIS0OGPST7
   :target: https://codecov.io/gh/arcanaframework/arcana-bids
.. image:: https://img.shields.io/pypi/pyversions/arcana-bids.svg
   :target: https://pypi.python.org/pypi/arcana-bids/
   :alt: Python versions
.. image:: https://img.shields.io/pypi/v/arcana-bids.svg
   :target: https://pypi.python.org/pypi/arcana-bids/
   :alt: Latest Version
.. image:: https://readthedocs.org/projects/arcana/badge/?version=latest
  :target: https://arcanaframework.github.io/arcana
  :alt: Documentation Status


An extension of the Arcana framework to work with Brain Imaging Data Structure (BIDS)
datasets and apps


Quick Installation
------------------

This extension can be installed for Python 3 using *pip*::

    $ pip3 install arcana-bids

This will also install the core Arcana_ package and any required dependencies.

License
-------

This work is licensed under a
`Creative Commons Attribution 4.0 International License <http://creativecommons.org/licenses/by/4.0/>`_

.. image:: https://i.creativecommons.org/l/by/4.0/88x31.png
  :target: http://creativecommons.org/licenses/by/4.0/
  :alt: Creative Commons Attribution 4.0 International License



.. _Arcana: http://arcana.readthedocs.io
